==> swh.web-0.2.15.tar.gz: swh.web-0.2.15/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2015-2019  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU Affero General Public License v3 or later
# See top-level LICENSE file for more information

from io import open
import os
from os import path

from setuptools import find_packages, setup

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def parse_requirements(name=None):
    if name:
        reqf = "requirements-%s.txt" % name
    else:
        reqf = "requirements.txt"

    requirements = []
    if not path.exists(reqf):
        return requirements

    with open(reqf) as f:
        for line in f.readlines():
            line = line.strip()
            if not line or line.startswith("#"):
                continue
            requirements.append(line)
    return requirements


# package generated static assets as module data files
data_files = []
for folder in ("static/", "assets/"):
    for root, _, files in os.walk(folder):
        root_files = [os.path.join(root, i) for i in files]
        data_files.append((os.path.join("share/swh/web", root), root_files))

setup(
    name="swh.web",
    description="Software Heritage Web UI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.7",
    author="Software Heritage developers",
    author_email="swh-devel@inria.fr",
    url="https://gitlab.softwareheritage.org/swh/devel/swh-web",
    packages=find_packages(),
    scripts=[],
    install_requires=parse_requirements() + parse_requirements("swh"),
    setup_requires=["setuptools-scm"],
    use_scm_version=True,
    extras_require={"testing": parse_requirements("test")},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",  # noqa
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
    ],
    project_urls={
        "Bug Reports": "https://gitlab.softwareheritage.org/swh/devel/swh-web/-/issues",
        "Funding": "https://www.softwareheritage.org/donate",
        "Source": "https://gitlab.softwareheritage.org/swh/devel/swh-web.git",
        "Documentation": "https://docs.softwareheritage.org/devel/swh-web/",
    },
    data_files=data_files,
)

==> swh.web-0.2.45.tar.gz: swh.web-0.2.45/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2015-2019  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU Affero General Public License v3 or later
# See top-level LICENSE file for more information

from io import open
import os
from os import path

from setuptools import find_packages, setup

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()


def parse_requirements(name=None):
    if name:
        reqf = "requirements-%s.txt" % name
    else:
        reqf = "requirements.txt"

    requirements = []
    if not path.exists(reqf):
        return requirements

    with open(reqf) as f:
        for line in f.readlines():
            line = line.strip()
            if not line or line.startswith("#"):
                continue
            requirements.append(line)
    return requirements


# package generated static assets as module data files
data_files = []
for folder in ("static/", "assets/"):
    for root, _, files in os.walk(folder):
        root_files = [os.path.join(root, i) for i in files]
        data_files.append((os.path.join("share/swh/web", root), root_files))

setup(
    name="swh.web",
    description="Software Heritage Web UI",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    python_requires=">=3.7",
    author="Software Heritage developers",
    author_email="swh-devel@inria.fr",
    url="https://gitlab.softwareheritage.org/swh/devel/swh-web",
    packages=find_packages(),
    scripts=[],
    install_requires=parse_requirements() + parse_requirements("swh"),
    setup_requires=["setuptools-scm"],
    use_scm_version=True,
    extras_require={"testing": parse_requirements("test")},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",  # noqa
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
    ],
    project_urls={
        "Bug Reports": "https://gitlab.softwareheritage.org/swh/devel/swh-web/-/issues",
        "Funding": "https://www.softwareheritage.org/donate",
        "Source": "https://gitlab.softwareheritage.org/swh/devel/swh-web.git",
        "Documentation": "https://docs.softwareheritage.org/devel/swh-web/",
    },
    data_files=data_files,
)
